;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "compile-angel" "20251116.2222"
  "Automatically Compile Elisp files (auto-compile alternative)."
  '((emacs "26.3"))
  :url "https://github.com/jamescherti/compile-angel.el"
  :commit "95a0d01dc9c6eeac5023465fadf8ab82726df097"
  :revdesc "95a0d01dc9c6"
  :keywords '("convenience"))
